@@ -53,6 +53,7 @@ from orca.scripts import default
 
 from .bookmarks import Bookmarks
 from .braille_generator import BrailleGenerator
+from .sound_generator import SoundGenerator
 from .speech_generator import SpeechGenerator
 from .tutorial_generator import TutorialGenerator
 from .script_utilities import Utilities
@@ -83,12 +84,15 @@ class Script(default.Script):
             _settingsManager.setSetting('caretNavigationEnabled', True)
         if _settingsManager.getSetting('sayAllOnLoad') == None:
             _settingsManager.setSetting('sayAllOnLoad', True)
+        if _settingsManager.getSetting('pageSummaryOnLoad') == None:
+            _settingsManager.setSetting('pageSummaryOnLoad', True)
 
         self._changedLinesOnlyCheckButton = None
         self._controlCaretNavigationCheckButton = None
         self._minimumFindLengthAdjustment = None
         self._minimumFindLengthLabel = None
         self._minimumFindLengthSpinButton = None
+        self._pageSummaryOnLoadCheckButton = None
         self._sayAllOnLoadCheckButton = None
         self._skipBlankCellsCheckButton = None
         self._speakCellCoordinatesCheckButton = None
@@ -259,6 +263,11 @@ class Script(default.Script):
 
         return liveregions.LiveRegionManager(self)
 
+    def getSoundGenerator(self):
+        """Returns the sound generator for this script."""
+
+        return SoundGenerator(self)
+
     def getSpeechGenerator(self):
         """Returns the speech generator for this script."""
 
@@ -325,11 +334,17 @@ class Script(default.Script):
         self._sayAllOnLoadCheckButton.set_active(value)
         generalGrid.attach(self._sayAllOnLoadCheckButton, 0, 4, 1, 1)
 
+        label = guilabels.PAGE_SUMMARY_UPON_LOAD
+        value = _settingsManager.getSetting('pageSummaryOnLoad')
+        self._pageSummaryOnLoadCheckButton = Gtk.CheckButton.new_with_mnemonic(label)
+        self._pageSummaryOnLoadCheckButton.set_active(value)
+        generalGrid.attach(self._pageSummaryOnLoadCheckButton, 0, 5, 1, 1)
+
         label = guilabels.CONTENT_LAYOUT_MODE
         value = _settingsManager.getSetting('layoutMode')
         self._layoutModeCheckButton = Gtk.CheckButton.new_with_mnemonic(label)
         self._layoutModeCheckButton.set_active(value)
-        generalGrid.attach(self._layoutModeCheckButton, 0, 5, 1, 1)
+        generalGrid.attach(self._layoutModeCheckButton, 0, 6, 1, 1)
 
         tableFrame = Gtk.Frame()
         grid.attach(tableFrame, 0, 1, 1, 1)
@@ -436,6 +451,7 @@ class Script(default.Script):
             'findResultsVerbosity': verbosity,
             'findResultsMinimumLength': self._minimumFindLengthSpinButton.get_value(),
             'sayAllOnLoad': self._sayAllOnLoadCheckButton.get_active(),
+            'pageSummaryOnLoad': self._pageSummaryOnLoadCheckButton.get_active(),
             'structuralNavigationEnabled': self._structuralNavigationCheckButton.get_active(),
             'structNavTriggersFocusMode': self._autoFocusModeStructNavCheckButton.get_active(),
             'caretNavigationEnabled': self._controlCaretNavigationCheckButton.get_active(),
@@ -656,12 +672,6 @@ class Script(default.Script):
         orca.setLocusOfFocus(None, context.obj, notifyScript=False)
         self.utilities.setCaretContext(context.obj, context.currentOffset)
 
-    def _getCtrlShiftSelectionsStrings(self):
-        return [messages.LINE_SELECTED_DOWN,
-                messages.LINE_UNSELECTED_DOWN,
-                messages.LINE_SELECTED_UP,
-                messages.LINE_UNSELECTED_UP]
-
     def inFocusMode(self):
         """ Returns True if we're in focus mode."""
 
@@ -755,8 +765,17 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, "BRAILLE: disabled", True)
             return
 
-        if not (self._lastCommandWasCaretNav or self._lastCommandWasStructNav) \
-           or self._inFocusMode or not self.utilities.inDocumentContent():
+        if self._inFocusMode or not self.utilities.inDocumentContent():
+            msg = "WEB: updating braille for non-browse-mode object %s" % obj
+            debug.println(debug.LEVEL_INFO, msg, True)
+            super().updateBraille(obj, **args)
+            return
+
+        if not self._lastCommandWasCaretNav \
+           and not self._lastCommandWasStructNav \
+           and not self.utilities.lastInputEventWasCaretNavWithSelection():
+            msg = "WEB: updating braille for unhandled navigation type %s" % obj
+            debug.println(debug.LEVEL_INFO, msg, True)
             super().updateBraille(obj, **args)
             return
 
@@ -1001,6 +1020,11 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             contents = self.utilities.getLineContentsAtOffset(newFocus, 0)
             utterances = self.speechGenerator.generateContents(contents)
+        elif self.utilities.lastInputEventWasPageNav():
+            msg = "WEB: New focus %s was scrolled to. Generating line contents." % newFocus
+            debug.println(debug.LEVEL_INFO, msg, True)
+            contents = self.utilities.getLineContentsAtOffset(newFocus, caretOffset)
+            utterances = self.speechGenerator.generateContents(contents)
         elif newFocus.getRole() == pyatspi.ROLE_HEADING:
             msg = "WEB: New focus %s is heading. Generating object contents." % newFocus
             debug.println(debug.LEVEL_INFO, msg, True)
@@ -1085,6 +1109,13 @@ class Script(default.Script):
 
         self.utilities.clearCachedObjects()
 
+        if _settingsManager.getSetting('pageSummaryOnLoad'):
+            msg = "WEB: Getting page summary for obj %s" % obj
+            debug.println(debug.LEVEL_INFO, msg, True)
+            summary = self.utilities.getPageSummary(obj)
+            if summary:
+                self.presentMessage(summary)
+
         obj, offset = self.utilities.getCaretContext()
 
         try:
@@ -1206,6 +1237,14 @@ class Script(default.Script):
             self.utilities.setCaretContext(obj, offset)
             return True
 
+        if self.utilities.lastInputEventWasPageNav() \
+           and not self.utilities.isLink(event.source):
+            msg = "WEB: Event handled: Caret moved due to scrolling"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            orca.setLocusOfFocus(event, obj)
+            self.utilities.setCaretContext(obj, offset)
+            return True
+
         text = self.utilities.queryNonEmptyText(event.source)
         if not text:
             if event.source.getRole() == pyatspi.ROLE_LINK:
@@ -1474,6 +1513,13 @@ class Script(default.Script):
             debug.println(debug.LEVEL_INFO, msg, True)
             return False
 
+        if self.utilities.lastInputEventWasPageNav():
+            msg = "WEB: Event handled: Focus changed due to scrolling"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            orca.setLocusOfFocus(event, obj)
+            self.utilities.setCaretContext(obj, offset)
+            return True
+
         wasFocused = obj.getState().contains(pyatspi.STATE_FOCUSED)
         obj.clearCache()
         isFocused = obj.getState().contains(pyatspi.STATE_FOCUSED)
@@ -1737,14 +1783,9 @@ class Script(default.Script):
             return True
 
         char = text.getText(event.detail1, event.detail1+1)
-        if char == self.EMBEDDED_OBJECT_CHARACTER:
-            msg = "WEB: Ignoring: Event offset is at embedded object"
-            debug.println(debug.LEVEL_INFO, msg, True)
-            return True
-
-        obj, offset = self.utilities.getCaretContext()
-        if obj and obj.parent and event.source in [obj.parent, obj.parent.parent]:
-            msg = "WEB: Ignoring: Source is context ancestor"
+        if char == self.EMBEDDED_OBJECT_CHARACTER \
+           and not self.utilities.lastInputEventWasCaretNavWithSelection():
+            msg = "WEB: Ignoring: Not selecting and event offset is at embedded object"
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
 
