@@ -69,6 +69,12 @@ userCustomizableSettings = [
     "brailleSelectorIndicator",
     "brailleLinkIndicator",
     "brailleAlignmentStyle",
+    "enableSound",
+    "soundVolume",
+    "playSoundForRole",
+    "playSoundForState",
+    "playSoundForPositionInSet",
+    "playSoundForValue",
     "enableBrailleMonitor",
     "verbalizePunctuationStyle",
     "presentToolTips",
@@ -77,6 +83,7 @@ userCustomizableSettings = [
     "speakBlankLines",
     "speakMultiCaseStringsAsWords",
     "speakNumbersAsDigits",
+    "speakMisspelledIndicator",
     "enabledSpokenTextAttributes",
     "enabledBrailledTextAttributes",
     "textAttributesBrailleIndicator",
@@ -214,6 +221,7 @@ speakCellHeaders             = True
 speakSpreadsheetCoordinates  = True
 speakMultiCaseStringsAsWords = False
 speakNumbersAsDigits         = False
+speakMisspelledIndicator     = True
 useColorNames                = True
 usePronunciationDictionary   = True
 sayAllStyle                  = SAYALL_STYLE_SENTENCE
@@ -244,6 +252,14 @@ brailleAlignmentStyle          = BRAILLE_ALIGN_BY_EDGE
 brailleAlignmentMargin         = 3
 brailleMaximumJump             = 8
 
+# Sound
+enableSound = True
+soundVolume = 0.5
+playSoundForRole = False
+playSoundForState = False
+playSoundForPositionInSet = False
+playSoundForValue = False
+
 # Keyboard and Echo
 keyboardLayout               = GENERAL_KEYBOARD_LAYOUT_DESKTOP
 orcaModifierKeys             = DESKTOP_MODIFIER_KEYS
