@@ -386,6 +386,9 @@ class SpeechGenerator(generator.Generator):
         if not role:
             return ''
 
+        if role == pyatspi.ROLE_LINK and obj.getState().contains(pyatspi.STATE_VISITED):
+            return object_properties.ROLE_VISITED_LINK
+
         nonlocalized = Atspi.role_get_name(role)
         atkRole = Atk.role_for_name(nonlocalized)
 
@@ -462,19 +465,15 @@ class SpeechGenerator(generator.Generator):
     def _generateMultiselectableState(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the multiselectable state of
-        the object.  This is typically for check boxes. If the object
+        the object.  This is typically for list boxes. If the object
         is not multiselectable, an empty array will be returned.
         """
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
-        result = []
         acss = self.voice(STATE)
-        if obj.getState().contains(pyatspi.STATE_MULTISELECTABLE) \
-           and obj.childCount:
-            result.append(self._script.formatting.getString(
-                mode='speech',
-                stringType='multiselect'))
+        result = super()._generateMultiselectableState(obj, **args)
+        if result:
             result.extend(acss)
         return result
 
@@ -925,28 +924,16 @@ class SpeechGenerator(generator.Generator):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
-        result = []
-        acss = self.voice(SYSTEM)
         if _settingsManager.getSetting('speechVerbosityLevel') \
-                == settings.VERBOSITY_LEVEL_VERBOSE:
-            if obj.getRole() == pyatspi.ROLE_TABLE_CELL:
-                cell = obj
-            else:
-                cell = self._script.utilities.ancestorWithRole(
-                    obj, [pyatspi.ROLE_TABLE_CELL], [pyatspi.ROLE_FRAME])
-            try:
-                table = cell.parent.queryTable()
-            except:
-                pass
-            else:
-                index = self._script.utilities.cellIndex(cell)
-                row = table.getRowAtIndex(index)
-                col = table.getColumnAtIndex(index)
-                if row + 1 == table.nRows and col + 1 == table.nColumns:
-                    result.append(messages.TABLE_END)
-        if result:
-            result.extend(acss)
-        return result
+           != settings.VERBOSITY_LEVEL_VERBOSE:
+            return []
+
+        if self._script.utilities.isLastCell(obj):
+            result = [messages.TABLE_END]
+            result.extend(self.voice(SYSTEM))
+            return result
+
+        return []
 
     #####################################################################
     #                                                                   #
@@ -1253,53 +1240,21 @@ class SpeechGenerator(generator.Generator):
         result.extend(self._getACSS(obj, result[0]))
         return result
 
-    def generateTextIndentation(self, obj, **args):
-        return self._generateTextIndentation(obj, **args)
-
     def _generateTextIndentation(self, obj, **args):
         """Speaks a summary of the number of spaces and/or tabs at the
         beginning of the given line.
 
         Arguments:
         - obj: the text object.
-        - line: the string to check for spaces and tabs.
         """
-        if _settingsManager.getSetting('onlySpeakDisplayedText'):
+
+        line, caretOffset, startOffset = self._script.getTextLineAtCaret(obj)
+        description = self._script.utilities.indentationDescription(line)
+        if not description:
             return []
 
-        acss = self.voice(SYSTEM)
-        if not _settingsManager.getSetting('enableSpeechIndentation'):
-            return []
-        line =  args.get('alreadyFocused', "")
-        if not line:
-            [line, caretOffset, startOffset] = \
-              self._script.getTextLineAtCaret(obj)
-
-        # For the purpose of speaking the text indentation, replace
-        # occurances the non breaking space character with spaces.
-        line = line.replace("\u00a0", " ")
-        spaceCount = 0
-        tabCount = 0
-        utterance = ""
-        offset = 0
-        while True:
-            while (offset < len(line)) and line[offset] == ' ':
-                spaceCount += 1
-                offset += 1
-            if spaceCount:
-                utterance += "%s " % messages.spacesCount(spaceCount)
-            while (offset < len(line)) and line[offset] == '\t':
-                tabCount += 1
-                offset += 1
-            if tabCount:
-                utterance += "%s " % messages.tabsCount(tabCount)
-            if not (spaceCount  or tabCount):
-                break
-            spaceCount  = tabCount = 0
-
-        result = [utterance]
-        if result and result[0]:
-            result.extend(acss)
+        result = [description]
+        result.extend(self.voice(SYSTEM))
         return result
 
     #####################################################################
@@ -1344,21 +1299,13 @@ class SpeechGenerator(generator.Generator):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
-        result = []
-        acss = self.voice(SYSTEM)
-        try:
-            value = obj.queryValue()
-        except NotImplementedError:
-            pass
-        else:
-            percentValue = \
-                (value.currentValue
-                 / (value.maximumValue - value.minimumValue)) \
-                * 100.0
-            result.append(messages.percentage(percentValue))
-        if result:
-            result.extend(acss)
-        return result
+        percentValue = self._script.utilities.getValueAsPercent(obj)
+        if percentValue is not None:
+            result = [percentValue]
+            result.extend(self.voice(SYSTEM))
+            return result
+
+        return []
 
     #####################################################################
     #                                                                   #
@@ -2281,31 +2228,6 @@ class SpeechGenerator(generator.Generator):
     #                                                                   #
     #####################################################################
 
-    def _getAlternativeRole(self, obj, **args):
-        if self._script.utilities.isMath(obj):
-            if self._script.utilities.isMathFraction(obj):
-                return 'ROLE_MATH_FRACTION'
-            if self._script.utilities.isMathRoot(obj):
-                return 'ROLE_MATH_ROOT'
-            if self._script.utilities.isMathSubOrSuperScript(obj):
-                return 'ROLE_MATH_SCRIPT_SUBSUPER'
-            if self._script.utilities.isMathUnderOrOverScript(obj):
-                return 'ROLE_MATH_SCRIPT_UNDEROVER'
-            if self._script.utilities.isMathMultiScript(obj):
-                return 'ROLE_MATH_MULTISCRIPT'
-            if self._script.utilities.isMathEnclose(obj):
-                return 'ROLE_MATH_ENCLOSED'
-            if self._script.utilities.isMathFenced(obj):
-                return 'ROLE_MATH_FENCED'
-            if self._script.utilities.isMathTable(obj):
-                return 'ROLE_MATH_TABLE'
-            if self._script.utilities.isMathTableRow(obj):
-                return 'ROLE_MATH_TABLE_ROW'
-        if self._script.utilities.isStatic(obj):
-            return 'ROLE_STATIC'
-
-        return args.get('role', obj.getRole())
-
     def _generatePause(self, obj, **args):
         if not _settingsManager.getSetting('enablePauseBreaks') \
            or args.get('eliminatePauses', False):
